==> aptitude_0.0.4a.orig.tar.gz: aptitude-0.0.4a/src/vs_progress.cc <==
// vs_progress.cc
//
//  Copyright 2000 Daniel Burrows
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING.  If not, write to
//  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//  Boston, MA 02111-1307, USA.
//
//  A vscreen_widget that also acts as a progress bar.

#include "vs_progress.h"

void vs_progress::display()
{
  int width,height;
  get_owner()->getmaxyx(height,width);
  int barsize;
  char percent_string[50];

  if(!Op.empty())
    {
      assert(Percent>=0 && Percent<=100);
      barsize=int(Percent*width/100.0);

      snprintf(percent_string, 50, ": %i%%", int(Percent));

      get_owner()->show_string_as_progbar(0,
					  height-1,
					  Op+percent_string,
					  COLOR_PAIR(get_color("pkgtree_progress", COLOR_BLUE, COLOR_YELLOW)),
					  COLOR_PAIR(vs_tree::get_status_color())|A_BOLD,
					  barsize,
					  width);
    }
  else
    get_owner()->display_status("", COLOR_PAIR(vs_tree::get_status_color())|A_BOLD);
}

void vs_progress::Update()
{
  get_tree()->show_status();
  get_owner()->refresh();
}

void vs_progress::Done()
{
  get_tree()->show_status();
  get_owner()->refresh();
}

==> aptitude_0.2.11.1.orig.tar.gz: aptitude-0.2.11.1/src/vs_progress.cc <==
// vs_progress.cc
//
//  Copyright 2000 Daniel Burrows
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING.  If not, write to
//  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//  Boston, MA 02111-1307, USA.
//
//  A vs_minibuf that also acts as a progress bar.

#include "aptitude.h"

#include "vs_progress.h"

void vs_progress::paint()
{
  int barsize;
  char percent_string[50];
  int width=getmaxx();

  if(!Op.empty())
    {
      assert(Percent>=0 && Percent<=100);
      barsize=int(Percent*width/100.0);

      snprintf(percent_string, 50, ": %i%%", int(Percent));

      show_string_as_progbar(0,
			     0,
			     Op+percent_string,
			     get_color("Progress"),
			     get_color("ScreenStatusColor"),
			     barsize,
			     width);
    }
  else
    {
      bkgd(get_color("ScreenStatusColor"));
      erase();
    }
}

bool vs_progress::get_cursorvisible()
{
  return false;
}

point vs_progress::get_cursorloc()
{
  return point(int(Percent*getmaxx()/100.0), 0);
}

void vs_progress::Update()
{
  if(CheckChange(0.7))
    {
      vscreen_update();
      vscreen_updatecursor();
      vscreen_tryupdate();
    }
}

void vs_progress::Done()
{
  vscreen_update();
  vscreen_updatecursor();
  vscreen_tryupdate();

  hide();
}
